/*
  Alarm.h
  Copyright (c) 1996-1999 Dwight D. Everhart.  All rights reserved.
  This source code has been released to the public.  Use is governed
  by the MiscKit license, which basically means you can use it for
  whatever purpose you like, commercial or non-commercial.  This code
  is provided AS IS.  No warranty is expressed or implied.
*/

#import <Foundation/NSObject.h>


@class Date;


@interface Alarm: NSObject <NSCoding, NSCopying>

{
   Date *alarmTime;
   id alarmTarget;
   SEL alarmMessage;
   BOOL executing;
}

+ (void) initialize;

+ (BOOL) isScheduled:     (Alarm *) alarm;
+ (BOOL) scheduleAlarm:   (Alarm *) alarm;
+ (void) unscheduleAlarm: (Alarm *) alarm;

+ (BOOL) executeAlarms: (id) sender;
+ (BOOL) executeAlarmsImmediately: (id) sender;
+ (void) scheduleNextExecution;
+ (void) cancelExecutions;

+ (void) freeAlarmAfterExecution: (Alarm *) freeMe;
+ (void) freeClassVariables;

- (id) init;
- (id) initWithAlarmTime: (Date *) theAlarmTime
  target: target andMessage: (SEL) message;
- (id) initWithCoder: (NSCoder *) aDecoder;
- (void) encodeWithCoder: (NSCoder *) aCoder;
- (id) copyWithZone: (NSZone *) zone;
- (void) dealloc;

- (BOOL) isScheduled;
- (BOOL) isScheduleable;
- (BOOL) isExecuting;

- (Date *) alarmTime;
- (id) alarmTarget;
- (SEL) alarmMessage;

- (void) setAlarmTime: (Date *) newTime;
- (void) setAlarmTarget: (id) newTarget;
- (void) setAlarmMessage: (SEL) newMessage;
- (void) setAlarmTime: (Date *) newTime
  target: (id) newTarget andMessage: (SEL) newMessage;

- (void) executeAlarm;

- (NSComparisonResult) compare: (id) anObject;
- (BOOL) isEqual: (id) anObject;

@end
