/*
  Appointment.h
  Copyright (c) 1996-1999 Dwight D. Everhart.  All rights reserved.
  This source code has been released to the public.  Use is governed
  by the MiscKit license, which basically means you can use it for
  whatever purpose you like, commercial or non-commercial.  This code
  is provided AS IS.  No warranty is expressed or implied.
*/

#import <Foundation/NSObject.h>

@class NSAttributedString, Date;


#define RI_NONE    0
#define RI_DAILY   1
#define RI_WEEKLY  2
#define RI_MONTHLY 3
#define RI_YEARLY  4

// Schedule levels -- regular appointments are ASL_EXACT; others are to-do items.
#define ASL_EXACT   0
#define ASL_DAY    10
#define ASL_WEEK   20
#define ASL_MONTH  30
#define ASL_YEAR   40
#define ASL_NONE   INT_MAX


@interface Appointment: NSObject

{
   NSString *title;
   NSAttributedString *descriptionText;
   Date *startDate;
   Date *endDate;
   int interval;
   int frequency;
   int duration;
   int scheduleLevel;
}

- (id) init;
- (id) copyWithZone: (NSZone *) zone;
- (void) dealloc;

@end


@interface Appointment (AppointmentAttributes)

- (NSString *) title;
- (NSAttributedString *) descriptionText;
- (Date *) startDate;
- (Date *) endDate;
- (int) interval;
- (int) frequency;
- (int) duration;
- (int) scheduleLevel;

- (BOOL) getNextOccuranceDate: (Date *) occuranceDate;
- (BOOL) isScheduledFor: (Date *) date;

- (NSComparisonResult) compare: (id) anObject;

@end


@interface Appointment (AppointmentActions)

- (void) setTitle:  (NSString *) newTitle;
- (void) setDescriptionText: (NSAttributedString *) newDescriptionText;
- (void) setStartDate:  (Date *) newStartDate andConstrain: (BOOL) constrain;
- (void) setEndDate:    (Date *) newEndDate;
- (void) setInterval:      (int) newInterval;
- (void) setFrequency:     (int) newFrequency;
- (void) setDuration:      (int) newDuration;
- (void) setScheduleLevel: (int) newScheduleLevel;

- (void) constrainScheduleDateToScheduleLevel;

- (void) bumpWithSelector: (SEL) bumpSelector;
- (void) bumpToNextDay;
- (void) bumpToNextWeek;
- (void) bumpToNextMonth;
- (void) bumpToNextYear;

@end
