/*
  Date.h
  Copyright (c) 1996-1999 Dwight D. Everhart.  All rights reserved.

  This source code has been released to the public.  Use is governed
  by the MiscKit license, which basically means you can use it for
  whatever purpose you like, commercial or non-commercial.  This code
  is provided AS IS.  No warranty is expressed or implied.
*/

#import <Foundation/NSObject.h>
#import <Foundation/NSDate.h>
#import <time.h>

@class NSCalendarDate, NSDate;


#define MONTHS_IN_YEAR    12
#define WEEKS_IN_YEAR     52
#define DAYS_IN_WEEK       7
#define FIRST_YEAR      1970
#define LAST_YEAR       2037
#define FIRST_MONTH        1
#define LAST_MONTH        12
#define FEBRUARY           2
#define DAYS_PER_WEEK      7
#define HOURS_PER_DAY     24
#define MINUTES_PER_HOUR  60
#define MINUTES_PER_DAY  (MINUTES_PER_HOUR * HOURS_PER_DAY)
#define MINUTES_PER_WEEK (MINUTES_PER_DAY  * DAYS_PER_WEEK)


@interface Date: NSObject <NSCopying>

{
   int year;    /* 1970 - 2037 */
   int month;   /* 1 - 12 */
   int day;     /* 1 - 31 */
   int minute;  /* 0 - (MINUTES_PER_DAY - 1) */
}

+ (Date *) now;

+ (int) weekStart;
+ (void) setWeekStart: (int) weekStart; /* 0-6 with Sunday == 0 */

+ (BOOL) isValidYear:  (int) aYear month: (int) aMonth day: (int) aDay;
+ (void) validateYear: (int) aYear month: (int) aMonth day: (int) aDay;
+ (BOOL) isLeapYear:   (int) aYear;

+ (int) weekdayForYear: (int) aYear month: (int) aMonth day: (int) aDay;
+ (int) numberOfMonthsInYear;
+ (int) numberOfWeeksInYear;
+ (int) numberOfDaysInWeek;
+ (int) numberOfDaysInMonth: (int) aMonth forYear: (int) aYear;
+ (int) numberOfDaysInYear: (int) aYear;
+ (int) earliestYear;
+ (int) latestYear;

- (id) init;
- (id) copyWithZone: (NSZone *) zone;

@end


@interface Date (DateAttributes)

- (int) minuteOfDay;      /* Minute of the day: 0-1440 */
- (int) dayOfMonth;       /* Day of the month:  1-31   */
- (int) monthOfYear;      /* Month of the year: 1-12   */
- (int) yearOfCommonEra;  /* Year: 1970 - 2037         */
- (int) weekday;          /* Day of the week: 0-6 with Sunday == 0 */
- (int) dayOfYear;        /* Day  of the year: 1-365   */
- (int) weekOfYear;       /* Week of the year: 1-52    */
- (int) numberOfMonthsInYear;
- (int) numberOfWeeksInYear;
- (int) numberOfDaysInWeek;
- (int) numberOfDaysInMonth;
- (int) numberOfDaysInYear;
- (int) earliestYear;
- (int) latestYear;
- (int) startDayOfMonth;

- (BOOL) isLeapYear;

- (NSCalendarDate *) calendarDate;

- (NSString *) description;

- (int) minutesUntil: (Date *) otherDate;
- (int) minutesSince: (Date *) otherDate;
- (int) daysUntil:    (Date *) otherDate;
- (int) daysSince:    (Date *) otherDate;
- (int) weeksUntil:   (Date *) otherDate;
- (int) weeksSince:   (Date *) otherDate;
- (int) monthsUntil:  (Date *) otherDate;
- (int) monthsSince:  (Date *) otherDate;
- (int) monthsWithDay: (int) aDay until: (Date *) otherDate;
- (int) monthsWithDay: (int) aDay since: (Date *) otherDate;
- (int) yearsUntil:   (Date *) otherDate;
- (int) yearsSince:   (Date *) otherDate;

- (unsigned int) hash;
- (BOOL) isEqual: (id) anObject;
- (NSComparisonResult) compare: (id) anObject;

@end


@interface Date (DateActions)

- (void) setMinute: (int) newMinute;
- (void) setDay:    (int) aDay;
- (void) setMonth:  (int) aMonth;
- (void) setYear:   (int) aYear;
- (void) setYear:   (int) year month: (int) month day: (int) day;

- (void) setDate: (Date *) otherDate;
- (void) setDateToTM: (const struct tm *) tm;
- (void) setDateToTime_t: (time_t) newTime;
- (void) setDateToTimeIntervalSince1970: (NSTimeInterval) newInterval;
- (void) setDateToNSDate: (NSDate *) nsDate;
- (void) setDateToCalendarDate: (NSCalendarDate *) calendarDate;
- (void) setDateToToday;
- (void) setToEarliestDate;
- (void) setToLatestDate;

- (void) setDayOfYear:  (int) newDayOfYear;
- (void) setWeekOfYear: (int) newWeekOfYear;

- (void) setDayToPreviousDay:       (int) newDay;
- (void) setDayToNextDay:           (int) newDay;
- (void) setDayToThisOrPreviousDay: (int) newDay;
- (void) setDayToThisOrNextDay:     (int) newDay;

- (void) setDayToPreviousWeekday:       (int) weekday;
- (void) setDayToNextWeekday:           (int) weekday;
- (void) setDayToThisOrPreviousWeekday: (int) weekday;
- (void) setDayToThisOrNextWeekday:     (int) weekday;
- (void) setDayToNearestWeekday:        (int) weekday;

- (void) setMonthToPreviousMonth:       (int) newMonth;
- (void) setMonthToNextMonth:           (int) newMonth;
- (void) setMonthToThisOrPreviousMonth: (int) newMonth;
- (void) setMonthToThisOrNextMonth:     (int) newMonth;

- (void) setDayToPreviousMonth:       (int) newMonth andDay: (int) newDay;
- (void) setDayToNextMonth:           (int) newMonth andDay: (int) newDay;
- (void) setDayToThisOrPreviousMonth: (int) newMonth andDay: (int) newDay;
- (void) setDayToThisOrNextMonth:     (int) newMonth andDay: (int) newDay;

- (void) changeMinuteBy: (int) delta;
- (void) incrementDay;
- (void) decrementDay;
- (void) changeDayBy:    (int) delta;
- (void) incrementWeek;
- (void) decrementWeek;
- (void) changeWeekBy:   (int) delta;
- (void) incrementMonth;
- (void) decrementMonth;
- (void) changeMonthBy:  (int) delta;
- (void) incrementYear;
- (void) decrementYear;
- (void) changeYearBy:   (int) delta;

@end
