/*
  Date.m
  Copyright (c) 1996-1999 Dwight D. Everhart.  All rights reserved.

  This source code has been released to the public.  Use is governed
  by the MiscKit license, which basically means you can use it for
  whatever purpose you like, commercial or non-commercial.  This code
  is provided AS IS.  No warranty is expressed or implied.
*/

#import "Date.h"
#import <Foundation/NSException.h>
#import <Foundation/NSString.h>

#ifdef GNUSTEP
#import <Foundation/NSCalendarDate.h>
#import <Foundation/NSTimeZone.h>
#endif

static int weekStart = 0; /* Defaults to Sunday. */

static int daysInMonth[] = {0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};

static Date *now;



@implementation Date



+ (Date *) now
{
   if (!now) {
      now = [[Date allocWithZone: [self zone]] init];
   } else {
      /* Get the current day. */
      [now setDateToToday];
   }

   return now;
}



+ (int) weekStart
{
   return weekStart;
}



+ (void) setWeekStart: (int) newWeekStart
{
   weekStart = newWeekStart;
}



+ (BOOL) isValidYear: (int) aYear month: (int) aMonth day: (int) aDay
{
   /* Is it a valid year? */
   if ((aYear < FIRST_YEAR) || (aYear > LAST_YEAR)) return NO;

   /* Is it a valid month? */
   if ((aMonth < FIRST_MONTH) || (aMonth > LAST_MONTH)) return NO;

   /* Is it a valid day? */
   if (aDay < 1) return NO;

   /* Is it Feburary on a leap year? */
   if ((aMonth == 2) && [self isLeapYear: aYear]) {
      if (aDay > 29) {
         return NO;
      }
   } else {
      if (aDay > daysInMonth[aMonth]) {
         return NO;
      }
   }

   /* It is valid! */
   return YES;
}



+ (void) validateYear: (int) aYear month: (int) aMonth day: (int) aDay
{
   if (![self isValidYear: aYear month: aMonth day: aDay]) {
      [NSException raise: NSInvalidArgumentException
                  format: @"Invalid combination: year = %d, month = %d, day = %d",
         aYear, aMonth, aDay];
   }
}



+ (BOOL) isLeapYear: (int) aYear
{
   return (((aYear % 4) == 0) && ((aYear % 100) != 0)) || ((aYear % 400) == 0);
}



+ (int) weekdayForYear: (int) aYear month: (int) aMonth day: (int) aDay
{
   NSCalendarDate *date;

   date = [NSCalendarDate dateWithYear: aYear month: aMonth day: aDay
                                  hour: 12 minute: 0 second: 0
                              timeZone: [NSTimeZone localTimeZone]];
   return [date dayOfWeek];
}



+ (int) numberOfMonthsInYear
{
   return MONTHS_IN_YEAR;
}



+ (int) numberOfWeeksInYear
{
   return WEEKS_IN_YEAR;
}



+ (int) numberOfDaysInWeek
{
   return DAYS_IN_WEEK;
}



+ (int) numberOfDaysInMonth: (int) aMonth forYear: (int) aYear
{
   if ((aMonth == FEBRUARY) && [self isLeapYear: aYear]) {
      return 29;
   } else {
      return daysInMonth[aMonth];
   }
}



+ (int) numberOfDaysInYear: (int) aYear
{
   if ([self isLeapYear: aYear]) {
      return 366;
   } else {
      return 365;
   }
}



+ (int) earliestYear
{
   return FIRST_YEAR;
}



+ (int) latestYear
{
   return LAST_YEAR;
}



- (id) init
{
   self = [super init];
   if (!self) return nil;

   [self setDateToToday];
   return self;
}



- (id) copyWithZone: (NSZone *) zone
{
   return NSCopyObject (self, 0, zone);
}



@end
