/*
  EmailMessage.h
  Copyright (c) 1996-1999 Dwight D. Everhart.  All rights reserved.
  This source code has been released to the public.  Use is governed
  by the MiscKit license, which basically means you can use it for
  whatever purpose you like, commercial or non-commercial.  This code
  is provided AS IS.  No warranty is expressed or implied.
*/

#import <Foundation/NSObject.h>
/* #import <ChronographerSource/FrameworkDefines.h> */
#import "FrameworkDefines.h"

@class NSMutableDictionary, NSString;


ChronographerSource_EXTERN NSString *EmailMessageSendFailureException;


@interface EmailMessage: NSObject

{
   @private
   NSMutableDictionary *envelope;
   NSString *addressee;
   NSString *body;
}

// The command should be the full path to an executable
// which accepts an email message on standard input
// and sends it to the address given as the first argument.
// It defaults to /usr/lib/sendmail.
+ (void) setEmailCommand: (NSString *) command;
+ (NSString *) emailCommand;

+ (id) emailMessageWithBody: (NSString *) bodyContents sentTo: (NSString *) to
  withSubject: (NSString *) subject;
+ (void) sendMessage: (NSString *) bodyContents to: (NSString *) to
  withSubject: (NSString *) subject;

- (id) init;
- (id) initWithBody: (NSString *) bodyContents sentTo: (NSString *) to
  withSubject: (NSString *) subject; // Designated initializer
- (void) dealloc;

- (void) setHeader: (NSString *) header to: (NSString *) contents;
- (NSString *) contentsOfHeader: (NSString *) header;

- (void) setFrom:      (NSString *) from;
- (void) setTo:        (NSString *) to;
- (void) setCc:        (NSString *) cc;
- (void) setSubject:   (NSString *) subject;
- (void) setReplyTo:   (NSString *) replyTo;
- (void) setSender:    (NSString *) sender;
- (void) setAddressee: (NSString *) anAddressee;
- (void) setBody:      (NSString *) bodyContents;

- (NSString *) from;
- (NSString *) to;
- (NSString *) cc;
- (NSString *) subject;
- (NSString *) replyTo;
- (NSString *) sender;
- (NSString *) addressee;
- (NSString *) body;

- (void) sendMessage;
- (void) sendMessageUsingCommand: (NSString *) command;

@end
