/*
  EmailReminder.m
  Copyright (c) 1996-1999 Dwight D. Everhart.  All rights reserved.

  This source code has been released to the public.  Use is governed
  by the MiscKit license, which basically means you can use it for
  whatever purpose you like, commercial or non-commercial.  This code
  is provided AS IS.  No warranty is expressed or implied.
*/

#import "EmailReminder.h"
#import "EmailMessage.h"
#import "Appointment.h"
#import "Date.h"
#import "setInstance.h"
#import <AppKit/AppKit.h>


#define CURRENT_VERSION 1


static BOOL disableEmails = NO;
static BOOL debug = NO;



@implementation EmailReminder



+ (void)initialize
{
   [super initialize];

   if ([self class] == [EmailReminder class]) {
      [self setVersion: CURRENT_VERSION];
   }
}



- (id) initWithAppointment: (Appointment *) appointment
{
   if (!(self = [super initWithAppointment: appointment])) return nil;
   addressee = [NSUserName() retain];
   return self;
}



- (void)dealloc
{
   [addressee release];
   [super dealloc];
}


- (NSString *) addressee
{
   return addressee;
}



- (void) setAddressee: (NSString *) newAddressee
{
   setInstance (addressee, newAddressee);
}


#define S_REMINDER_FAILED_TITLE NSLocalizedString(@"Email Reminder Failed", @"Title of a panel")

#define S_EMAIL_PROLOG NSLocalizedString(@"This is a reminder from Chronographer:\n\n", @"Text displayed at the beginning of an email reminder message")

#define S_EMAIL_APPT_LINE NSLocalizedString(@"%@ at %@.\n\n", @"Text displayed in an email message for a reminder for an appointment, with the first %@ being the appointment title and the second %@ being the time and date at which the appointment occurs")

#define S_EMAIL_TODO_LINE NSLocalizedString(@"%@ on %@.\n\n", @"Text displayed in an email message for a reminder for a to-do item, with the first %@ being the to-do item's title and the second %@ being the date on which the item should be done")


- (void) doReminder
{
   [super doReminder];

   if (disableEmails) {
      NSLog (@"EmailReminder: Reminder for '%@' would've been executed here",
             [appt title]);
   } else {
      NSMutableString *message = [NSMutableString stringWithCapacity: 1024];

      if (debug) {
         [message appendFormat: @"Reminder[%@]:\n\n",
            [[NSProcessInfo processInfo] globallyUniqueString]];
      } else {
         [message appendString: S_EMAIL_PROLOG];
      }

      [message appendFormat: S_EMAIL_APPT_LINE,
      [appt title], [apptTime description]];

      [EmailMessage sendMessage: message to: addressee withSubject: [appt title]];
   }
}



@end

