/*
  SoundReminder.m
  Copyright (c) 1996-1999 Dwight D. Everhart.  All rights reserved.

  This source code has been released to the public.  Use is governed
  by the MiscKit license, which basically means you can use it for
  whatever purpose you like, commercial or non-commercial.  This code
  is provided AS IS.  No warranty is expressed or implied.
*/

#import "SoundReminder.h"
#import "Appointment.h"
#import "setInstance.h"
#import <AppKit/AppKit.h>

#ifndef WIN32
#ifndef GNUSTEP
#import <SoundKit/SoundKit.h>
#endif
#endif

#define CURRENT_VERSION 0



@implementation SoundReminder



+ (void) initialize
{
   [super initialize];

   if ([self class] == [SoundReminder class]) {
      [self setVersion: CURRENT_VERSION];
   }
}



- (id) initWithAppointment: (Appointment *) appointment
{
   if (!(self = [super initWithAppointment: appointment])) return nil;
   setInstance (soundFilename, @"");
   return self;
}



- (NSString *) soundFilename
{
   return soundFilename;
}



- (void) setSoundFilename: (NSString *) newSoundFilename
{
   setInstance (soundFilename, newSoundFilename);
}


#define S_SRERR_TITLE NSLocalizedString(@"Sound Reminder Error", @"Title of a panel")

#define S_SRERR_MSG1 NSLocalizedString(@"Could not play sound for reminder '%@': no sound file specified", @"Error message displayed when a sound reminder couldn't be played because the sound file wasn't specified.  The %@ is the title of the reminder's appointment")

#define S_SRERR_MSG2 NSLocalizedString(@"Could not play sound for reminder '%@': could not load sound file %@", @"Error message displayed when the file for a sound reminder couldn't be loaded.  The first %@ is the title of the reminder's appointment; the second %@ is the file name")


- (void) doReminder
{
#ifndef WIN32
#ifndef GNUSTEP
   Sound *sound;

   if (![super doReminder]) return nil;

   if (!soundFilename || !soundFilename[0]) {
      NSRunAlertPanel(S_SRERR_TITLE, S_SRERR_MSG1, [appt title], nil, nil, NULL);
      return;
   }

   sound = [Sound findSoundFor:soundFilename]];
   if (!sound) {
      NSRunAlertPanel(S_SRERR_TITLE, S_SRERR_MSG2, [appt title], soundFilename, nil, NULL, NULL);
      return;
   }

   [sound play];
#else
#warning We need to add sound support for GNUSTEP.
#endif
#else
#warning We need to add sound support fow Windows.
#endif
}



@end
