/*
  setInstance.h
  Copyright (c) 1996-1999 Dwight D. Everhart.  All rights reserved.
  This source code has been released to the public.  Use is governed
  by the MiscKit license, which basically means you can use it for
  whatever purpose you like, commercial or non-commercial.  This code
  is provided AS IS.  No warranty is expressed or implied.

  Thread-safe macros for setting an object's instance variables.
  The retain must come before the release to be thread safe.
  (If not, another thread could ask for _ivar_ between "[_oldValue_ release]"
  and "_ivar_ = [_newValue_ retain]" -- _ivar_ might not exist at that point.)
*/

#define setInstance(_ivar_,_object_) do {	\
   id _oldValue_ = _ivar_;			\
   id _newValue_ = (_object_);			\
   if (_ivar_ != _newValue_) {			\
      _ivar_ = [_newValue_ retain];		\
      [_oldValue_ release];			\
   }						\
} while (0)

#define setInstanceByCopy(_ivar_,_object_) do {	\
   id _oldValue_ = _ivar_;			\
   id _newValue_ = (_object_);			\
   if (_ivar_ != _newValue_) {			\
      _ivar_ = [_newValue_ copyWithZone: [self zone]];	\
      [_oldValue_ release];			\
   }						\
} while (0)

#define setInstanceByMutableCopy(_ivar_,_object_) do {	\
   id _oldValue_ = _ivar_;			\
   id _newValue_ = (_object_);			\
   if (_ivar_ != _newValue_) {			\
      _ivar_ = [_newValue_ mutableCopyWithZone: [self zone]];	\
      [_oldValue_ release];			\
   }						\
} while (0)

